---
name: Bug report
about: Create a report to help us improve freegenes python

---

## Expected Behavior

[ Please describe the behavior that are expecting ]

## Actual Behavior

## Steps to Reproduce

[ Please provide detailed steps for reproducing the issue and reproducible Code Snippet ]

## Context

[provide more detailed introduction to the issue itself . This is for make a reproducible issue.]
* Operating System:
* Python version:
* FreeGenes Python version:

## Failure Logs

 [ log or files here. If relevant, include a screenshot]

## Possible Fix

[ the suggest fixes or reasons for the bug]
